==> gaea-iesms-datacenter-1.0-20240721.041937-1-sources.jar: com/gaea/iesms/bm/datacenter/mapper/MeasDataCumFreezeCurveDao.java <==
package com.gaea.iesms.bm.datacenter.mapper;

import com.easesource.data.bean.Pager;
import com.easesource.data.bean.Sorter;
import com.easesource.data.jdbc.mybatis.CrudMapper;
import com.gaea.iesms.core.model.entity.datacenter.MeasDataCumFreezeCurveDo;
import com.gaea.iesms.bm.datacenter.model.response.MeasDataCumFreezeCurveVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 *
 * @author Nick Zhang
 */
@Mapper
public interface MeasDataCumFreezeCurveDao extends CrudMapper<MeasDataCumFreezeCurveDo, Long> {

    /**
     * 批量更新
     * @param measDataCumFreezeCurveDoList
     *          累积量曲线数据实体列表
     * @return
     */
    int batchInsertOrUpdate(@Param("list") List<MeasDataCumFreezeCurveDo> measDataCumFreezeCurveDoList);

    /**
     * 通过量测点标识和量测项编码获取量测点最新数据实体
     *
     * @param measPointId
     *          量测点标识
     * @param measItemCode
     *          量测项编码
     * @param gmtMeasFreeze
     *          量测曲线时间
     * @return
     *          累积量曲线数据
     */
    MeasDataCumFreezeCurveDo getByMeasPointIdAndMeasItemCodeAndGmtMeasFreeze(@Param("measPointId") Long measPointId, @Param("measItemCode") String measItemCode, @Param("gmtMeasFreeze") long gmtMeasFreeze);

    /**
     * 通过量测点标识和量测项编码获取量测点最新数据视图
     *
     * @param measPointId
     *          量测点标识
     * @param measItemCode
     *          量测项编码
     * @param gmtMeasFreeze
     *          量测曲线时间
     * @return
     *          累积量曲线数据
     */
    MeasDataCumFreezeCurveVo getMeasDataCumFreezeCurveVoByMeasPointIdAndMeasItemCodeAndGmtMeasFreeze(@Param("measPointId") Long measPointId, @Param("measItemCode") String measItemCode, @Param("gmtMeasFreeze") long gmtMeasFreeze);

    /**
     * 通过量测点标识和量测项编码获取量测点最新数据视图
     *
     * @param measPointIdSet
     *          量测点标识
     * @param measItemCodeSet
     *          量测项编码
     * @param gmtMeasFreeze
     *          量测曲线时间
     * @return
     *          累积量曲线数据
     */
    List<MeasDataCumFreezeCurveVo> getMeasDataCumFreezeCurveVoListByMeasPointIdSetAndMeasItemCodeSetAndGmtMeasFreeze(@Param("measPointIdSet") Set<Long> measPointIdSet, @Param("measItemCodeSet") Set<String> measItemCodeSet, @Param("gmtMeasFreeze") long gmtMeasFreeze);

    /**
     * 查询结果个数
     *
     * @param params
     *          查询参数
     * @return
     *          查询结果个数
     */
    int getMeasDataCumFreezeCurveVoCount(@Param("params") Map<String, Object> params);

    /**
     * 查询结果列表
     *
     * @param params
     *          查询参数
     * @param sorter
     *          排序
     * @param pager
     *          分页
     * @return
     *          查询结果列表
     */
    List<MeasDataCumFreezeCurveVo> getMeasDataCumFreezeCurveVoList(@Param("params") Map<String, Object> params, @Param("sorter") Sorter sorter, @Param("pager") Pager pager);

}

==> gaea-iesms-datacenter-1.0-20241231.073331-2-sources.jar: com/gaea/iesms/bm/datacenter/mapper/MeasDataCumFreezeCurveDao.java <==
package com.gaea.iesms.bm.datacenter.mapper;

import com.easesource.data.bean.Pager;
import com.easesource.data.bean.Sorter;
import com.easesource.data.jdbc.mybatis.CrudMapper;
import com.gaea.iesms.core.model.entity.datacenter.MeasDataCumFreezeCurveDo;
import com.gaea.iesms.bm.datacenter.model.response.MeasDataCumFreezeCurveVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 *
 * @author Nick Zhang
 */
@Mapper
public interface MeasDataCumFreezeCurveDao extends CrudMapper<MeasDataCumFreezeCurveDo, Long> {

    /**
     * 批量更新
     *
     * @param measDataCumFreezeCurveDoList 累积量曲线数据实体列表
     * @return
     */
    int batchInsertOrUpdate(@Param("list") List<MeasDataCumFreezeCurveDo> measDataCumFreezeCurveDoList);

    /**
     * 通过量测点标识和量测项编码获取量测点最新数据实体
     *
     * @param measPointId   量测点标识
     * @param measItemCode  量测项编码
     * @param gmtMeasFreeze 量测曲线时间
     * @return 累积量曲线数据
     */
    MeasDataCumFreezeCurveDo getByMeasPointIdAndMeasItemCodeAndGmtMeasFreeze(@Param("measPointId") Long measPointId, @Param("measItemCode") String measItemCode, @Param("gmtMeasFreeze") long gmtMeasFreeze);

    /**
     * 通过量测点标识和量测项编码获取量测点最新数据视图
     *
     * @param measPointId   量测点标识
     * @param measItemCode  量测项编码
     * @param gmtMeasFreeze 量测曲线时间
     * @return 累积量曲线数据
     */
    MeasDataCumFreezeCurveVo getMeasDataCumFreezeCurveVoByMeasPointIdAndMeasItemCodeAndGmtMeasFreeze(@Param("measPointId") Long measPointId, @Param("measItemCode") String measItemCode, @Param("gmtMeasFreeze") long gmtMeasFreeze);

    /**
     * 通过量测点标识和量测项编码获取量测点最新数据视图
     *
     * @param measPointIdSet  量测点标识
     * @param measItemCodeSet 量测项编码
     * @param gmtMeasFreeze   量测曲线时间
     * @return 累积量曲线数据
     */
    List<MeasDataCumFreezeCurveVo> getMeasDataCumFreezeCurveVoListByMeasPointIdSetAndMeasItemCodeSetAndGmtMeasFreeze(@Param("measPointIdSet") Set<Long> measPointIdSet, @Param("measItemCodeSet") Set<String> measItemCodeSet, @Param("gmtMeasFreeze") long gmtMeasFreeze);

    /**
     * 查询结果个数
     *
     * @param params 查询参数
     * @return 查询结果个数
     */
    int getMeasDataCumFreezeCurveVoCount(@Param("params") Map<String, Object> params);

    /**
     * 查询结果列表
     *
     * @param params 查询参数
     * @param sorter 排序
     * @param pager  分页
     * @return 查询结果列表
     */
    List<MeasDataCumFreezeCurveVo> getMeasDataCumFreezeCurveVoList(@Param("params") Map<String, Object> params, @Param("sorter") Sorter sorter, @Param("pager") Pager pager);

    /**
     * 查询结果列表
     *
     * @param params 查询参数
     * @param sorter 排序
     * @param pager  分页
     * @return 查询结果列表
     */
    List<MeasDataCumFreezeCurveVo> getMeasDataCumFreezeCurveList(@Param("params") Map<String, Object> params, @Param("sorter") Sorter sorter, @Param("pager") Pager pager);

}
